DEFINE_TEST(test_acl_freebsd)
DEFINE_TEST(test_acl_nfs4)
DEFINE_TEST(test_acl_pax)
DEFINE_TEST(test_acl_posix1e)
DEFINE_TEST(test_archive_api_feature)
DEFINE_TEST(test_archive_clear_error)
DEFINE_TEST(test_archive_md5)
DEFINE_TEST(test_archive_rmd160)
DEFINE_TEST(test_archive_sha1)
DEFINE_TEST(test_archive_sha256)
DEFINE_TEST(test_archive_sha384)
DEFINE_TEST(test_archive_sha512)
DEFINE_TEST(test_archive_getdate)
DEFINE_TEST(test_archive_match_owner)
DEFINE_TEST(test_archive_match_path)
DEFINE_TEST(test_archive_match_time)
DEFINE_TEST(test_archive_pathmatch)
DEFINE_TEST(test_archive_read_close_twice)
DEFINE_TEST(test_archive_read_close_twice_open_fd)
DEFINE_TEST(test_archive_read_close_twice_open_filename)
DEFINE_TEST(test_archive_read_next_header_empty)
DEFINE_TEST(test_archive_read_next_header_raw)
DEFINE_TEST(test_archive_read_open2)
DEFINE_TEST(test_archive_read_set_filter_option)
DEFINE_TEST(test_archive_read_set_format_option)
DEFINE_TEST(test_archive_read_set_option)
DEFINE_TEST(test_archive_read_set_options)
DEFINE_TEST(test_archive_read_support)
DEFINE_TEST(test_archive_set_error)
DEFINE_TEST(test_archive_string)
DEFINE_TEST(test_archive_string_conversion)
DEFINE_TEST(test_archive_write_set_filter_option)
DEFINE_TEST(test_archive_write_set_format_option)
DEFINE_TEST(test_archive_write_set_option)
DEFINE_TEST(test_archive_write_set_options)
DEFINE_TEST(test_bad_fd)
DEFINE_TEST(test_compat_bzip2)
DEFINE_TEST(test_compat_cpio)
DEFINE_TEST(test_compat_gtar)
DEFINE_TEST(test_compat_gzip)
DEFINE_TEST(test_compat_lzip)
DEFINE_TEST(test_compat_lzma)
DEFINE_TEST(test_compat_mac)
DEFINE_TEST(test_compat_pax_libarchive_2x)
DEFINE_TEST(test_compat_solaris_pax_sparse)
DEFINE_TEST(test_compat_solaris_tar_acl)
DEFINE_TEST(test_compat_tar_hardlink)
DEFINE_TEST(test_compat_xz)
DEFINE_TEST(test_compat_zip)
DEFINE_TEST(test_empty_write)
DEFINE_TEST(test_entry)
DEFINE_TEST(test_entry_strmode)
DEFINE_TEST(test_extattr_freebsd)
DEFINE_TEST(test_filter_count)
DEFINE_TEST(test_fuzz)
DEFINE_TEST(test_gnutar_filename_encoding)
DEFINE_TEST(test_link_resolver)
DEFINE_TEST(test_open_failure)
DEFINE_TEST(test_open_fd)
DEFINE_TEST(test_open_file)
DEFINE_TEST(test_open_filename)
DEFINE_TEST(test_pax_filename_encoding)
DEFINE_TEST(test_read_compress_program)
DEFINE_TEST(test_read_data_large)
DEFINE_TEST(test_read_disk)
DEFINE_TEST(test_read_disk_directory_traversals)
DEFINE_TEST(test_read_disk_entry_from_file)
DEFINE_TEST(test_read_extract)
DEFINE_TEST(test_read_file_nonexistent)
DEFINE_TEST(test_read_format_7zip)
DEFINE_TEST(test_read_format_ar)
DEFINE_TEST(test_read_format_cab)
DEFINE_TEST(test_read_format_cab_filename)
DEFINE_TEST(test_read_format_cpio_afio)
DEFINE_TEST(test_read_format_cpio_bin)
DEFINE_TEST(test_read_format_cpio_bin_Z)
DEFINE_TEST(test_read_format_cpio_bin_be)
DEFINE_TEST(test_read_format_cpio_bin_bz2)
DEFINE_TEST(test_read_format_cpio_bin_gz)
DEFINE_TEST(test_read_format_cpio_bin_lzip)
DEFINE_TEST(test_read_format_cpio_bin_lzma)
DEFINE_TEST(test_read_format_cpio_bin_xz)
DEFINE_TEST(test_read_format_cpio_filename)
DEFINE_TEST(test_read_format_cpio_odc)
DEFINE_TEST(test_read_format_cpio_svr4_bzip2_rpm)
DEFINE_TEST(test_read_format_cpio_svr4_gzip)
DEFINE_TEST(test_read_format_cpio_svr4_gzip_rpm)
DEFINE_TEST(test_read_format_cpio_svr4c_Z)
DEFINE_TEST(test_read_format_empty)
DEFINE_TEST(test_read_format_gtar_filename)
DEFINE_TEST(test_read_format_gtar_gz)
DEFINE_TEST(test_read_format_gtar_lzma)
DEFINE_TEST(test_read_format_gtar_sparse)
DEFINE_TEST(test_read_format_iso_Z)
DEFINE_TEST(test_read_format_iso_multi_extent)
DEFINE_TEST(test_read_format_iso_xorriso)
DEFINE_TEST(test_read_format_isojoliet_bz2)
DEFINE_TEST(test_read_format_isojoliet_long)
DEFINE_TEST(test_read_format_isojoliet_rr)
DEFINE_TEST(test_read_format_isojoliet_versioned)
DEFINE_TEST(test_read_format_isorr_bz2)
DEFINE_TEST(test_read_format_isorr_ce)
DEFINE_TEST(test_read_format_isorr_new_bz2)
DEFINE_TEST(test_read_format_isorr_rr_moved)
DEFINE_TEST(test_read_format_isozisofs_bz2)
DEFINE_TEST(test_read_format_lha)
DEFINE_TEST(test_read_format_lha_filename)
DEFINE_TEST(test_read_format_mtree)
DEFINE_TEST(test_read_format_pax_bz2)
DEFINE_TEST(test_read_format_rar)
DEFINE_TEST(test_read_format_raw)
DEFINE_TEST(test_read_format_tar)
DEFINE_TEST(test_read_format_tar_empty_filename)
DEFINE_TEST(test_read_format_tar_filename)
DEFINE_TEST(test_read_format_tbz)
DEFINE_TEST(test_read_format_tgz)
DEFINE_TEST(test_read_format_tlz)
DEFINE_TEST(test_read_format_txz)
DEFINE_TEST(test_read_format_tz)
DEFINE_TEST(test_read_format_ustar_filename)
DEFINE_TEST(test_read_format_xar)
DEFINE_TEST(test_read_format_zip)
DEFINE_TEST(test_read_format_zip_filename)
DEFINE_TEST(test_read_large)
DEFINE_TEST(test_read_pax_truncated)
DEFINE_TEST(test_read_position)
DEFINE_TEST(test_read_truncated)
DEFINE_TEST(test_read_truncated_filter)
DEFINE_TEST(test_read_uu)
DEFINE_TEST(test_sparse_basic)
DEFINE_TEST(test_tar_filenames)
DEFINE_TEST(test_tar_large)
DEFINE_TEST(test_ustar_filename_encoding)
DEFINE_TEST(test_ustar_filenames)
DEFINE_TEST(test_write_compress)
DEFINE_TEST(test_write_compress_bzip2)
DEFINE_TEST(test_write_compress_gzip)
DEFINE_TEST(test_write_compress_lzip)
DEFINE_TEST(test_write_compress_lzma)
DEFINE_TEST(test_write_compress_program)
DEFINE_TEST(test_write_compress_xz)
DEFINE_TEST(test_write_disk)
DEFINE_TEST(test_write_disk_failures)
DEFINE_TEST(test_write_disk_hardlink)
DEFINE_TEST(test_write_disk_lookup)
DEFINE_TEST(test_write_disk_perms)
DEFINE_TEST(test_write_disk_secure)
DEFINE_TEST(test_write_disk_sparse)
DEFINE_TEST(test_write_disk_symlink)
DEFINE_TEST(test_write_disk_times)
DEFINE_TEST(test_write_format_7zip)
DEFINE_TEST(test_write_format_ar)
DEFINE_TEST(test_write_format_cpio)
DEFINE_TEST(test_write_format_cpio_empty)
DEFINE_TEST(test_write_format_cpio_newc)
DEFINE_TEST(test_write_format_cpio_odc)
DEFINE_TEST(test_write_format_gnutar)
DEFINE_TEST(test_write_format_iso9660)
DEFINE_TEST(test_write_format_iso9660_boot)
DEFINE_TEST(test_write_format_iso9660_empty)
DEFINE_TEST(test_write_format_iso9660_filename)
DEFINE_TEST(test_write_format_iso9660_zisofs)
DEFINE_TEST(test_write_format_mtree)
DEFINE_TEST(test_write_format_mtree_fflags)
DEFINE_TEST(test_write_format_pax)
DEFINE_TEST(test_write_format_shar_empty)
DEFINE_TEST(test_write_format_tar)
DEFINE_TEST(test_write_format_tar_empty)
DEFINE_TEST(test_write_format_tar_sparse)
DEFINE_TEST(test_write_format_tar_ustar)
DEFINE_TEST(test_write_format_xar)
DEFINE_TEST(test_write_format_xar_empty)
DEFINE_TEST(test_write_format_zip)
DEFINE_TEST(test_write_format_zip_empty)
DEFINE_TEST(test_write_format_zip_no_compression)
DEFINE_TEST(test_write_open_memory)
DEFINE_TEST(test_zip_filename_encoding)
